==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/de/modify.php <==
﻿<?php

global $modify_text;
$modify_text = array (

'modify'          =>  'Ändern',
'noticefrom'      =>  'Nachricht von',
'hasopened'       =>  'hat eine neue Flyspray-Aufgabe geöffnet und Ihnen zugeteilt:',
'newtask'         =>  'Neue Aufgabe:',
'moreinfonew'     =>  'Sie können mehr über diese Aufgabe auf folgender Flyspray-Seite erfahren:',
'newtaskcategory' =>  'Eine neue Flyspray-Aufgabe wurde in dieser Kategorie geöffnet',
'categoryowner'   =>  'Sie erhalten diese Nachricht, weil Sie als Kategorieinhaber geführt werden.',
'tasksummary'     =>  'Aufgabenzusammenfassung:',
'newtaskadded'    =>  'Ihre neue Aufgabe wurde hinzugefügt.',
'waitwhiletransfer'=>  'Sie werden weitergeleitet...',
'clicknowait'     =>  'Weiter',
'summaryanddetails'=>  'Sie müssen sowohl Zusammenfassung als auch Details ausfüllen.',
'goback'          =>  'Zurück.',

'summary'         =>  'Zusammenfassung:',
'tasktype'        =>  'Aufgabentyp:',
'category'        =>  'Kategorie:',
'status'          =>  'Status:',
'operatingsystem' =>  'Betriebssystem:',
'severity'        =>  'Schweregrad:',
'reportedversion' =>  'Berichtete Version:',
'dueinversion'    =>  'Fällige Version:',
'percentcomplete' =>  'Prozent erledigt:',
'details'         =>  'Details:',

'messagefrom'     =>  'Dies ist eine Nachricht vom Flyspray Bugtracking-System auf',
'hasjustmodified' =>  'hat soeben folgende Aufgabe verändert.',
'changedfields'   =>  'Veränderte Felder sind mit Sternchen hervorgehoben (**)',
'moreinfomodify'  =>  'Mehr Informationen zu dieser Aufgabe auf',

'task'            =>  'Aufgabe',
'nolongerassigned'=>  'Folgende Aufgabe ist Ihnen nicht länger zugeteilt. Stattdessen ist dafür zuständig:',
'hasassigned'     =>  'hat Ihnen die folgende Flyspray-Aufgabe zugeteilt:',

'taskupdated'     =>  'Aufgabe wurde aktualisiert.',

'hasclosedassigned'=>  'hat die folgende Flyspray-Aufgabe geschlossen, die Ihnen zugeteilt war:',
'reasonforclosing'=>  'Grund für Schließung:',
'noone'           =>  'Niemand',
'unassigned'      =>  'Nicht zugeteilt',

'hasclosed'       =>  'hat die folgende Aufgabe geschlossen:',
'youonnotify'     =>  'Sie erhalten diese Nachricht, weil Sie auf der Benachrichtigungsliste geführt sind.',
'taskclosed'      =>  'Aufgabe wurde geschlossen.',
'returntotask'    =>  'Zurück zu den Aufgabendetails',
'backtoindex'     =>  'Zurück zur Aufgabenliste',
'noclosereason'   =>  'Sie haben keinen Grund für die Schließung der Aufgabe angegeben.',
'hasreopened'     =>  'hat folgende Flyspray-Aufgabe wieder geöffnet, die Sie geschlossen hatten:',
'taskreopened'    =>  'Aufgabe wurde wieder geöffnet.',
'backtotask'      =>  'Zurück zur Aufgabe.',

'commentadded'    =>  'Kommentar wurde hinzugefügt.',
'commenttoassigned'=>  'hat einen Kommentar zu einer Aufgabe hinzugefügt, die zugeteilt ist:',
'commenttotask'   =>  'hat folgenden Kommentar zur Aufgabe abgegeben.',
'nocommententered'=>  'Sie sollten wirklich einen Kommentar schreiben, bevor Sie das Formular abschicken.',

'fillinfields'    =>  'Sie haben nicht alle Felder ausgefüllt.',
'notcurrentpass'  =>  'Das ist nicht Ihr aktuelles Passwort!',
'passchanged'     =>  'Ihr Passwort wurde geändert.',
'closewindow'     =>  'Sie können dieses Fenster jetzt schließen.',
'passnomatch'     =>  'Neues Passwort und Bestätigung stimmen nicht überein!',

'usernametaken'   =>  'Dieser Benutzername existiert bereits.',
'newusercreated'  =>  'Neues Benutzerkonto wurde angelegt.',
'accountcreated'  =>  'Ihr Konto wurde angelegt.',
'newuserwarning'  =>  'Beachten Sie, dass Ihr Konto möglicherweise erst von einem Administrator aktiviert werden muss. Bitte haben Sie deshalb etwas Geduld, wenn Sie sich nicht einloggen können.',
'nomatchpass'     =>  'Ihre Passwörter stimmen nicht überein!',
'confirmwrong'    =>  'Bestätigungscode ungültig!',
'formnotcomplete' =>  'Formular wurde nicht vollständig ausgefüllt.',

'groupnametaken'  =>  'Dieser Gruppenname existiert bereits.',
'newgroupadded'   =>  'Neue Gruppe hinzugefügt.',

'optionssaved'    =>  'Flyspray-Optionen gespeichert.',

'hasuploaded'     =>  'hat eine Datei an eine Aufgabe angehängt, die Ihnen zugeteilt ist:',
'hasattached'     =>  'hat eine Datei an folgende Aufgabe angehängt:',
'filename'        =>  'Dateiname:',
'description'     =>  'Beschreibung:',
'fileuploaded'    =>  'Datei wurde hochgeladen.',
'fileerror'       =>  'Fehler beim Hochladen der Datei. Vielleicht stimmen die Berechtigungen für das <code>attachments</code> Verzeichnis nicht.',
'contactadmin'    =>  'Kontaktieren Sie den Administrator dieses Projektes.',
'selectfileerror' =>  'Sie haben keine Datei ausgewählt.',

'userupdated'     =>  'Benutzerdetails wurden aktualisiert',
'realandemail'    =>  'Sie haben keinen Realnamen und/oder keine E-Mail-Adresse eingegeben.',

'groupupdated'    =>  'Gruppendefinition aufgefrischt.',
'groupanddesc'    =>  'Sie haben keinen Gruppennamen und/oder keine Beschreibung eingegeben.',

'fillallfields'   =>  'Bitte füllen Sie alle Felder aus.',
'listupdated'     =>  'Liste wurde aktualisiert.',
'listitemadded'   =>  'Neues Listenelement hinzugefügt.',

'relatedadded'    =>  'Verwandte Aufgabe zur Liste hinzugefügt.',
'relatederror'    =>  'Diese Aufgabe ist bereits auf der Verwandtschaftsliste.',

'relatedremoved'  =>  'Verwandte Aufgabe von der Liste entfernt.',

'notifyadded'     =>  'Benutzer zur Benachrichtigungsliste hinzugefügt.',
'notifyerror'     =>  'Dieser Benutzer ist bereits auf der Benachrichtigungsliste für diese Aufgabe.',

'notifyremoved'   =>  'Benutzer von der Benachrichtigungsliste entfernt.',

'editcommentsaved'=>  'Geänderten Kommentar gespeichert.',
'commentdeleted'  =>  'Kommentar wurde gelöscht.',



// Added in version 0.9.5

'project'           =>  'Projekt:',
'gotonewtask'       =>  'Zu den Details der soeben erstellten Aufgabe',
'addanother'        =>  'Weitere Aufgabe zu diesem Projekt hinzufügen',
'projectcreated'    =>  'Neues Projekt wurde erstellt. Folgen sie untenstehendem Link, um Kategorien, Betriebssysteme und Versionslisten einzurichten.',
'customiseproject'  =>  'Dieses Projekt anpassen',
'projectupdated'    =>  'Projekteinstellungen gespeichert.',
'emptytitle'        =>  'Bitte geben Sie einen Projekttitel an.',
'loginbelow'        =>  'Sie können sich nun über das Formular unten auf dieser Seite einloggen.',
'attachmentdeleted' =>  'Anhang wurde gelöscht.',


// Added in 0.9.6

'reminderadded'     =>   'Ihre Erinnerung wurde erstellt.',
'reminderdeleted'   =>   'Die gewählte Erinnerung wurde gelöscht.',
'flyspraytask'      =>   'Flyspray-Aufgabe',
'fieldsmissing'     =>   'Felder ohne oder mit ungültigen Werten wurden ignoriert.',
'relatedinvalid'    =>   'Aufgabe nicht vorhanden.',
'relatedproject'    =>   'Die gewählte Aufgabe gehört zu einem anderen Projekt.',
'addanyway'         =>   'Trotzdem hinzufügen',
'cancel'            =>   'Abbrechen',
'alreadyedited'     =>   'Die Aufgabe wurde von einem anderen Benutzer bearbeitet, während Sie Ihre Änderungen vorgenommen haben.',
'saveanyway'        =>   'Meine Änderungen speichern',
'priority'          =>   'Priorität',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/de/modify.php <==
<?php

global $modify_text;
$modify_text = array (

'modify'          =>  'Ändern',
'noticefrom'      =>  'Nachricht von',
'hasopened'       =>  'hat eine neue Flyspray-Aufgabe geöffnet und Ihnen zugeteilt:',
'newtask'         =>  'Neue Aufgabe:',
'moreinfonew'     =>  'Sie können mehr über diese Aufgabe auf folgender Flyspray-Seite erfahren:',
'newtaskcategory' =>  'Eine neue Flyspray-Aufgabe wurde in dieser Kategorie geöffnet',
'categoryowner'   =>  'Sie erhalten diese Nachricht, weil Sie als Kategorieinhaber geführt werden.',
'tasksummary'     =>  'Aufgabenzusammenfassung:',
'newtaskadded'    =>  'Ihre neue Aufgabe wurde hinzugefügt.',
'waitwhiletransfer'=>  'Sie werden weitergeleitet...',
'clicknowait'     =>  'Weiter',
'summaryanddetails'=>  'Sie müssen sowohl Zusammenfassung als auch Details ausfüllen.',
'goback'          =>  'Zurück.',

'summary'         =>  'Zusammenfassung:',
'tasktype'        =>  'Aufgabentyp:',
'category'        =>  'Kategorie:',
'status'          =>  'Status:',
'operatingsystem' =>  'Betriebssystem:',
'severity'        =>  'Schweregrad:',
'reportedversion' =>  'Berichtete Version:',
'dueinversion'    =>  'Fällige Version:',
'percentcomplete' =>  'Prozent erledigt:',
'details'         =>  'Details:',

'messagefrom'     =>  'Dies ist eine Nachricht vom Flyspray Bugtracking-System auf',
'hasjustmodified' =>  'hat soeben folgende Aufgabe verändert.',
'changedfields'   =>  'Veränderte Felder sind mit Sternchen hervorgehoben (**)',
'moreinfomodify'  =>  'Mehr Informationen zu dieser Aufgabe auf',

'task'            =>  'Aufgabe',
'nolongerassigned'=>  'Folgende Aufgabe ist Ihnen nicht länger zugeteilt. Stattdessen ist dafür zuständig:',
'hasassigned'     =>  'hat Ihnen die folgende Flyspray-Aufgabe zugeteilt:',

'taskupdated'     =>  'Aufgabe wurde aktualisiert.',

'hasclosedassigned'=>  'hat die folgende Flyspray-Aufgabe geschlossen, die Ihnen zugeteilt war:',
'reasonforclosing'=>  'Grund für Schließung:',
'noone'           =>  'Niemand',
'unassigned'      =>  'Nicht zugeteilt',

'hasclosed'       =>  'hat die folgende Aufgabe geschlossen:',
'youonnotify'     =>  'Sie erhalten diese Nachricht, weil Sie auf der Benachrichtigungsliste geführt sind.',
'taskclosed'      =>  'Aufgabe wurde geschlossen.',
'returntotask'    =>  'Zurück zu den Aufgabendetails',
'backtoindex'     =>  'Zurück zur Aufgabenliste',
'noclosereason'   =>  'Sie haben keinen Grund für die Schließung der Aufgabe angegeben.',
'hasreopened'     =>  'hat folgende Flyspray-Aufgabe wieder geöffnet, die Sie geschlossen hatten:',
'taskreopened'    =>  'Aufgabe wurde wieder geöffnet.',
'backtotask'      =>  'Zurück zur Aufgabe.',

'commentadded'    =>  'Kommentar wurde hinzugefügt.',
'commenttoassigned'=>  'hat einen Kommentar zu einer Aufgabe hinzugefügt, die zugeteilt ist:',
'commenttotask'   =>  'hat folgenden Kommentar zur Aufgabe abgegeben.',
'nocommententered'=>  'Sie sollten wirklich einen Kommentar schreiben, bevor Sie das Formular abschicken.',

'fillinfields'    =>  'Sie haben nicht alle Felder ausgefüllt.',
'notcurrentpass'  =>  'Das ist nicht Ihr aktuelles Passwort!',
'passchanged'     =>  'Ihr Passwort wurde geändert.',
'closewindow'     =>  'Sie können dieses Fenster jetzt schließen.',
'passnomatch'     =>  'Neues Passwort und Bestätigung stimmen nicht überein!',

'usernametaken'   =>  'Dieser Benutzername existiert bereits.',
'newusercreated'  =>  'Neues Benutzerkonto wurde angelegt.',
'accountcreated'  =>  'Ihr Konto wurde angelegt.',
'newuserwarning'  =>  'Beachten Sie, dass Ihr Konto möglicherweise erst von einem Administrator aktiviert werden muss. Bitte haben Sie deshalb etwas Geduld, wenn Sie sich nicht einloggen können.',
'nomatchpass'     =>  'Ihre Passwörter stimmen nicht überein!',
'confirmwrong'    =>  'Bestätigungscode ungültig!',
'formnotcomplete' =>  'Formular wurde nicht vollständig ausgefüllt.',

'groupnametaken'  =>  'Dieser Gruppenname existiert bereits.',
'newgroupadded'   =>  'Neue Gruppe hinzugefügt.',

'optionssaved'    =>  'Flyspray-Optionen gespeichert.',

'hasuploaded'     =>  'hat eine Datei an eine Aufgabe angehängt, die Ihnen zugeteilt ist:',
'hasattached'     =>  'hat eine Datei an folgende Aufgabe angehängt:',
'filename'        =>  'Dateiname:',
'description'     =>  'Beschreibung:',
'fileuploaded'    =>  'Datei wurde hochgeladen.',
'fileerror'       =>  'Fehler beim Hochladen der Datei. Vielleicht stimmen die Berechtigungen für das <code>attachments</code> Verzeichnis nicht.',
'contactadmin'    =>  'Kontaktieren Sie den Administrator dieses Projektes.',
'selectfileerror' =>  'Sie haben keine Datei ausgewählt.',

'userupdated'     =>  'Benutzerdetails wurden aktualisiert',
'realandemail'    =>  'Sie haben keinen Realnamen und/oder keine E-Mail-Adresse eingegeben.',

'groupupdated'    =>  'Gruppendefinition aufgefrischt.',
'groupanddesc'    =>  'Sie haben keinen Gruppennamen und/oder keine Beschreibung eingegeben.',

'fillallfields'   =>  'Bitte füllen Sie alle Felder aus.',
'listupdated'     =>  'Liste wurde aktualisiert.',
'listitemadded'   =>  'Neues Listenelement hinzugefügt.',

'relatedadded'    =>  'Verwandte Aufgabe zur Liste hinzugefügt.',
'relatederror'    =>  'Diese Aufgabe ist bereits auf der Verwandtschaftsliste.',

'relatedremoved'  =>  'Verwandte Aufgabe von der Liste entfernt.',

'notifyadded'     =>  'Benutzer zur Benachrichtigungsliste hinzugefügt.',
'notifyerror'     =>  'Dieser Benutzer ist bereits auf der Benachrichtigungsliste für diese Aufgabe.',

'notifyremoved'   =>  'Benutzer von der Benachrichtigungsliste entfernt.',

'editcommentsaved'=>  'Geänderten Kommentar gespeichert.',
'commentdeleted'  =>  'Kommentar wurde gelöscht.',


// Added in version 0.9.5
'project'           =>  'Projekt:',
'gotonewtask'       =>  'Zu den Details der soeben erstellten Aufgabe',
'addanother'        =>  'Weitere Aufgabe zu diesem Projekt hinzufügen',
'projectcreated'    =>  'Neues Projekt wurde erstellt. Folgen sie untenstehendem Link, um Kategorien, Betriebssysteme und Versionslisten einzurichten.',
'customiseproject'  =>  'Dieses Projekt anpassen',
'projectupdated'    =>  'Projekteinstellungen gespeichert.',
'emptytitle'        =>  'Bitte geben Sie einen Projekttitel an.',
'loginbelow'        =>  'Sie können sich nun über das Formular unten auf dieser Seite einloggen.',
'attachmentdeleted' =>  'Anhang wurde gelöscht.',


// Added in 0.9.6
'reminderadded'     =>  'Ihre Erinnerung wurde erstellt.',
'reminderdeleted'   =>  'Die gewählte Erinnerung wurde gelöscht.',
'flyspraytask'      =>  'Flyspray-Aufgabe',
'fieldsmissing'     =>  'Felder ohne oder mit ungültigen Werten wurden ignoriert.',
'relatedinvalid'    =>  'Aufgabe nicht vorhanden.',
'relatedproject'    =>  'Die gewählte Aufgabe gehört zu einem anderen Projekt.',
'addanyway'         =>  'Trotzdem hinzufügen',
'cancel'            =>  'Abbrechen',
'alreadyedited'     =>  'Die Aufgabe wurde von einem anderen Benutzer bearbeitet, während Sie Ihre Änderungen vorgenommen haben.',
'saveanyway'        =>  'Meine Änderungen speichern',
'priority'          =>  'Priorität',

// Added in version 0.9.7
'nouserselected'    =>  'Keinen Bneutzer ausgewählt. Markieren Sie mindestens einen Benutzer und versuchen Sie es erneut.',
'groupswitchupdated'=>  'Benutzergruppen erfolgreich geändert.',
'takenownership'    =>  'Diese Aufgabe ist nun Ihnen zugeteilt.',
'adminrequestmade'  =>  'Ein Projektmanager wurde über Ihre Anfrage informiert.',
'newdepnotify'      =>  'Eine neue Abhängigkeit wurde zur folgenden Aufgabe hinzugefügt:',
'dependadded'       =>  'Abhängigkeit wurde hinzugefügt',
'dependaddfailed'   =>  'Sie können diese Aufgabe im Moment nicht als Abhängigkeit hinzufügen',
'depremoved'        =>  'Abhängigkeit wurde entfernt',
'newdepis'          =>  'Die neue Abhängigkeit ist',
'magicurlsent'      =>  'Eine Nachricht mit einem Link zum Abschließen des Vorganges wurde an Ihre Benachrichtigungsadresse geschickt.',
'changefspass'      =>  'Flyspray-Passwort ändern',
'magicurlmessage'   =>  'Bitte folgen Sie diesem Link, um Ihr Passwort zu ändern:',
'erroronform'       =>  'Bei der Verarbeitung der Formulareingaben ist ein Problem aufgetreten',
'addressused'       =>  'Diese Adresse wurde verwendet, um ein Flyspray-Benutzerkonto anzulegen. Wenn Sie diese Nachricht nicht erwartet haben, ignorieren und löschen Sie sie bitte. Rufen Sie die folgende Seite auf, um Ihre Anmeldung abzuschließen:',
'confirmcodeis'     =>  'Ihr Bestätigungscode:',
'codesent'          =>  'Ihr Bestätigungscode wurde abgeschickt. Bitte folgen Sie den in der Nachricht enthaltenen Anweisungen.',
'taskmadeprivate'   =>  'Diese Aufgabe wurde versteckt',
'taskmadepublic'    =>  'Diese Aufgabe wurde wieder öffentlich gemacht',
'realandnotify'     =>  'Sie müssen Ihren Namen angeben und entweder das Feld für die E-Mail-Adresse oder die Jabber-ID ausfüllen.',


);
?>
